@@ -339,104 +339,6 @@ ERROR_FIXES = {
 }
 
 
-ERROR_FIXES = {
-    # Configuration Errors
-    ErrorCode.CONFIG_NOT_FOUND: "Create a configuration file using the default template",
-    ErrorCode.CONFIG_INVALID: "Fix the configuration file according to the schema",
-    ErrorCode.CONFIG_MISSING_FIELD: "Add the required field to the configuration file",
-    ErrorCode.CONFIG_INVALID_VALUE: "Update the configuration value to match the expected format",
-    ErrorCode.CONFIG_VERSION_PATTERN_INVALID: "Use a valid semantic version pattern (e.g., '\\d+\\.\\d+\\.\\d+')",
-    ErrorCode.CONFIG_VALIDATION_ERROR: "Fix configuration validation errors",
-    ErrorCode.CONFIG_FILE_NOT_FOUND: "Create a configuration file",
-    ErrorCode.CONFIG_PARSE_ERROR: "Fix configuration parse errors",
-    
-    # Environment Errors
-    ErrorCode.ENV_VAR_MISSING: "Set the required environment variable",
-    ErrorCode.ENV_VAR_INVALID: "Update the environment variable with a valid value",
-    ErrorCode.PYTHON_VERSION_UNSUPPORTED: "Use Python 3.8 or later",
-    ErrorCode.GIT_NOT_INSTALLED: "Install Git using your system's package manager",
-    ErrorCode.UV_NOT_INSTALLED: "Install UV using 'pip install uv'",
-    
-    # Package Structure Errors
-    ErrorCode.PYPROJECT_NOT_FOUND: "Create a pyproject.toml file in the project root",
-    ErrorCode.PYPROJECT_INVALID: "Fix the pyproject.toml file according to the PEP 621 specification",
-    ErrorCode.SRC_DIR_NOT_FOUND: "Create a src directory in the project root",
-    ErrorCode.PACKAGE_DIR_NOT_FOUND: "Create the package directory under src/",
-    ErrorCode.INIT_PY_NOT_FOUND: "Create an __init__.py file in the package directory",
-    ErrorCode.README_NOT_FOUND: "Create a README.md file in the project root",
-    ErrorCode.LICENSE_NOT_FOUND: "Create a LICENSE file in the project root",
-    ErrorCode.CHANGELOG_NOT_FOUND: "Create a CHANGELOG.md file in the project root",
-    ErrorCode.TESTS_DIR_NOT_FOUND: "Create a tests directory in the project root",
-    
-    # Build Errors
-    ErrorCode.BUILD_FAILED: "Check the build output for specific errors and fix them",
-    ErrorCode.BUILD_INVALID_PACKAGE: "Ensure the package structure follows Python packaging standards",
-    ErrorCode.BUILD_MISSING_DEPENDENCY: "Add the missing dependency to pyproject.toml",
-    ErrorCode.BUILD_INVALID_ENTRY_POINT: "Fix the entry point configuration in pyproject.toml",
-    ErrorCode.BUILD_INVALID_CLASSIFIERS: "Update classifiers to use valid PyPI classifiers",
-    
-    # Version Errors
-    ErrorCode.VERSION_INVALID: "Use a valid semantic version (e.g., '1.0.0')",
-    ErrorCode.VERSION_NOT_FOUND: "Add version string to the specified files",
-    ErrorCode.VERSION_MISMATCH: "Ensure version strings match across all files",
-    ErrorCode.VERSION_BUMP_FAILED: "Manually update version strings in the specified files",
-    ErrorCode.VERSION_VALIDATION_ERROR: "Fix version validation errors",
-    ErrorCode.VERSION_TAG_EXISTS: "Use a different version tag",
-    
-    # Git Errors
-    ErrorCode.GIT_REPO_NOT_FOUND: "Initialize a Git repository with 'git init'",
-    ErrorCode.GIT_REMOTE_NOT_FOUND: "Add a Git remote with 'git remote add origin <url>'",
-    ErrorCode.GIT_PUSH_FAILED: "Ensure you have write access to the repository",
-    ErrorCode.GIT_TAG_FAILED: "Ensure the tag doesn't already exist",
-    ErrorCode.GIT_RELEASE_FAILED: "Check GitHub permissions and release settings",
-    ErrorCode.GIT_DIRTY_WORKSPACE: "Commit or stash changes before proceeding",
-    ErrorCode.GIT_VALIDATION_ERROR: "Fix Git validation errors",
-    ErrorCode.GIT_INIT_FAILED: "Initialize Git repository",
-    ErrorCode.GIT_COMMIT_FAILED: "Commit changes to Git",
-    
-    # PyPI Errors
-    ErrorCode.PYPI_AUTH_FAILED: "Check your PyPI token and permissions",
-    ErrorCode.PYPI_UPLOAD_FAILED: "Fix package build issues and try again",
-    ErrorCode.PYPI_PACKAGE_EXISTS: "Bump the version number before publishing",
-    ErrorCode.PYPI_INVALID_CREDENTIALS: "Update your PyPI credentials",
-    ErrorCode.PYPI_VALIDATION_ERROR: "Fix PyPI validation errors",
-    ErrorCode.PYPI_BUILD_FAILED: "Fix PyPI build issues and try again",
-    
-    # GitHub Errors
-    ErrorCode.GITHUB_AUTH_FAILED: "Check your GitHub token and permissions",
-    ErrorCode.GITHUB_REPO_EXISTS: "Use a different repository name or delete the existing one",
-    ErrorCode.GITHUB_CREATE_FAILED: "Check your GitHub permissions and repository settings",
-    ErrorCode.GITHUB_RELEASE_FAILED: "Ensure the tag exists and you have release permissions",
-    ErrorCode.GITHUB_API_ERROR: "Check the GitHub API status and your request format",
-    
-    # Validation Errors
-    ErrorCode.VALIDATION_FAILED: "Fix all validation errors before proceeding",
-    ErrorCode.VALIDATION_PACKAGE_NAME: "Use a valid Python package name (lowercase, no spaces)",
-    ErrorCode.VALIDATION_VERSION_FORMAT: "Use semantic versioning (MAJOR.MINOR.PATCH)",
-    ErrorCode.VALIDATION_DEPENDENCIES: "Fix dependency specifications in pyproject.toml",
-    ErrorCode.VALIDATION_ENTRY_POINTS: "Fix entry point configuration in pyproject.toml",
-    ErrorCode.VALIDATION_CLASSIFIERS: "Use valid PyPI classifiers",
-    
-    # Testing Errors
-    ErrorCode.TESTING_VALIDATION_ERROR: "Fix testing validation errors",
-    ErrorCode.TEST_EXECUTION_FAILED: "Fix test execution errors",
-    ErrorCode.DOCKER_BUILD_FAILED: "Fix Docker build issues",
-    
-    # Package Errors
-    ErrorCode.PACKAGE_VALIDATION_ERROR: "Fix package validation errors",
-    ErrorCode.PACKAGE_BUILD_FAILED: "Fix package build issues",
-    ErrorCode.PACKAGE_PUBLISH_FAILED: "Fix package publish issues",
-    
-    # Changelog Errors
-    ErrorCode.CHANGELOG_VALIDATION_ERROR: "Fix changelog validation errors",
-    ErrorCode.CHANGELOG_GENERATION_FAILED: "Manually generate changelog",
-    
-    # Generic Errors
-    ErrorCode.UNKNOWN_ERROR: "Check the error message and logs for more details",
-    ErrorCode.OPERATION_CANCELLED: "Check the error message and logs for more details",
-}
-
-
 def handle_error(error: Exception) -> None:
     """Handle an error and provide helpful information."""
     import logging
@@ -444,6 +346,7 @@ def handle_error(error: Exception) -> None:
     from rich.console import Console
     from rich.panel import Panel
     from rich.text import Text
+    from python_release_master.core.templates import DEFAULT_CONFIG
     
     console = Console(stderr=True)
     log = logging.getLogger("python_release_master")
@@ -453,7 +356,7 @@ def handle_error(error: Exception) -> None:
             code=error.code,
             message=error.message,
             description=ERROR_DESCRIPTIONS[error.code],
-            fix=ERROR_FIXES[error.code],
+            fix=ERROR_FIXES.get(error.code, "Fix the error according to the instructions below"),
             context=error.context,
         )
         
@@ -467,15 +370,30 @@ def handle_error(error: Exception) -> None:
         content.append(f"{error_info.message}\n\n")
         content.append("Description: ", style="bold")
         content.append(f"{error_info.description}\n\n")
-        content.append("How to fix: ", style="bold green")
-        content.append(error_info.fix)
+        
+        if error.fix_instructions:
+            content.append("How to fix:\n", style="bold green")
+            for instruction in error.fix_instructions:
+                content.append(f"  {instruction}\n")
+        else:
+            content.append("How to fix: ", style="bold green")
+            content.append(error_info.fix)
         
         if error_info.context:
-            content.append("\n\nContext:\n", style="bold")
+            content.append("\nContext:\n", style="bold")
             for key, value in error_info.context.items():
                 content.append(f"  {key}: ", style="dim")
                 content.append(f"{value}\n")
         
+        if error.code == ErrorCode.CONFIG_NOT_FOUND:
+            content.append("\nTemplate:\n", style="bold green")
+            content.append(DEFAULT_CONFIG.format(
+                module_name="your_package",
+                package_name="your-package",
+                owner="your-username",
+                description="Your package description"
+            ))
+        
         console.print(Panel(content, title=title, border_style="red"))
         log.debug("Full traceback:", exc_info=True)
     else:
